==> nextcloud-app-mail-3.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/oc.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Mail important",
    "No message found yet" : "Pas cap de messatge trobat",
    "Unread mail" : "Mail pas legit",
    "Important" : "Important",
    "Work" : "Professional(a)",
    "Personal" : "Personal",
    "Mail" : "Mail",
    "Mails" : "Mails",
    "Name" : "Nom",
    "Password" : "Senhal",
    "IMAP Settings" : "Paramètres IMAP",
    "None" : "Pas cap",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Password" : "Senhal IMAP",
    "SMTP Settings" : "Paramètres SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Connecting" : "Connexion",
    "Save" : "Salvar",
    "Connect" : "Connectar",
    "Password required" : "Senhal requerit",
    "Account settings" : "Paramètres de compte",
    "Signature" : "Signatura",
    "Mail server" : "Servidor email",
    "Go back" : "Revenir en arrière",
    "Email address" : "Adreça mail",
    "Cancel" : "Anullar",
    "From" : "De",
    "Write message …" : "Escriure un messatge…",
    "Monday morning" : "Diluns matin",
    "Send" : "Mandar",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Confirm" : "Confirmar",
    "Favorite" : "Favorit",
    "Read" : "Legit",
    "Select" : "Select",
    "More actions" : "Mai d’accions",
    "Back" : "Retorn",
    "All day" : "Tota la jornada",
    "Create" : "Crear",
    "Comment" : "Comentaris",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Choose" : "Causir",
    "Other" : "Autre",
    "Reply" : "Respondre",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Move" : "Move",
    "Quota" : "Quota",
    "Loading …" : "Cargament…",
    "Mark all as read" : "Marcar totes coma legits",
    "Edit name" : "Modificar lo nom",
    "Clear cache" : "Voidar l'escondedor",
    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
    "Refresh" : "Refrescar",
    "Retry" : "Tornar ensajar",
    "Sending …" : "Mandadís…",
    "Delete" : "Suprimir",
    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
    "Add" : "Apondre",
    "Close" : "Tampar",
    "Body" : "Còs",
    "Tags" : "Etiquetas",
    "Clear" : "Escafar",
    "Search" : "Recercar",
    "Date" : "Data",
    "Disabled" : "Desactivat",
    "Enabled" : "Activada",
    "Custom" : "Personalizats",
    "Mark as unread" : "Marcar coma pas legit",
    "Mark as read" : "Marcar coma legit",
    "Remove" : "Suprimir",
    "Untitled event" : "Eveniment sens títol",
    "Train" : "Tren",
    "Reset" : "Reïnicializar",
    "Client ID" : "ID client",
    "General" : "Generals",
    "User" : "User",
    "Host" : "Òste",
    "Port" : "Pòrt",
    "Valid until" : "Valid fins a",
    "Certificate" : "Certificat",
    "Submit" : "Transmetre",
    "Keyboard shortcut" : "Acorchis de clavièr",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Archive" : "Archius",
    "Account connected" : "Compte connectat",
    "All" : "Tot",
    "Drafts" : "Borrolhons",
    "Favorites" : "Favorits",
    "All inboxes" : "Totas las bóstias",
    "Inbox" : "Bóstia de recepcion",
    "Junk" : "Indesirables",
    "Sent" : "Mandats",
    "Trash" : "Escobilhièr",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Message sent" : "Messatge mandat",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Continue to %s" : "Contunhar cap a %s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-3.6.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/oc.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Mail important",
    "No message found yet" : "Pas cap de messatge trobat",
    "Unread mail" : "Mail pas legit",
    "Important" : "Important",
    "Work" : "Professional(a)",
    "Personal" : "Personal",
    "Mail" : "Mail",
    "Mails" : "Mails",
    "Name" : "Nom",
    "Password" : "Senhal",
    "IMAP Settings" : "Paramètres IMAP",
    "None" : "Pas cap",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Password" : "Senhal IMAP",
    "SMTP Settings" : "Paramètres SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Connecting" : "Connexion",
    "Save" : "Salvar",
    "Connect" : "Connectar",
    "Password required" : "Senhal requerit",
    "Account settings" : "Paramètres de compte",
    "Signature" : "Signatura",
    "Mail server" : "Servidor email",
    "Rename alias" : "Renomenar l’àlias",
    "Go back" : "Revenir en arrière",
    "Email address" : "Adreça mail",
    "Cancel" : "Anullar",
    "List" : "Tièra",
    "Register" : "S'inscriure",
    "Keyboard" : "Clavièr",
    "Archive" : "Archius",
    "Delete" : "Suprimir",
    "Search" : "Recercar",
    "Send" : "Mandar",
    "Refresh" : "Refrescar",
    "From" : "De",
    "Write message …" : "Escriure un messatge…",
    "Monday morning" : "Diluns matin",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Choose" : "Causir",
    "Confirm" : "Confirmar",
    "No messages" : "Cap de messatge",
    "Favorite" : "Favorit",
    "Read" : "Legit",
    "Select" : "Select",
    "More actions" : "Mai d’accions",
    "Back" : "Retorn",
    "All day" : "Tota la jornada",
    "Description" : "Descripcion",
    "Create" : "Crear",
    "Comment" : "Comentaris",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Other" : "Autre",
    "Reply" : "Respondre",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Move" : "Move",
    "Quota" : "Quota",
    "Loading …" : "Cargament…",
    "Mark all as read" : "Marcar totes coma legits",
    "Edit name" : "Modificar lo nom",
    "Clear cache" : "Voidar l'escondedor",
    "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
    "Retry" : "Tornar ensajar",
    "Sending …" : "Mandadís…",
    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
    "Add" : "Apondre",
    "Close" : "Tampar",
    "Body" : "Còs",
    "Tags" : "Etiquetas",
    "Clear" : "Escafar",
    "Date" : "Data",
    "Disabled" : "Desactivat",
    "Enabled" : "Activada",
    "Custom" : "Personalizats",
    "Mark as unread" : "Marcar coma pas legit",
    "Mark as read" : "Marcar coma legit",
    "Remove" : "Suprimir",
    "Untitled event" : "Eveniment sens títol",
    "Train" : "Tren",
    "Reset" : "Reïnicializar",
    "Client ID" : "ID client",
    "General" : "Generals",
    "User" : "User",
    "Host" : "Òste",
    "Port" : "Pòrt",
    "Valid until" : "Valid fins a",
    "Certificate" : "Certificat",
    "Submit" : "Transmetre",
    "Account connected" : "Compte connectat",
    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
    "All" : "Tot",
    "Drafts" : "Borrolhons",
    "Favorites" : "Favorits",
    "All inboxes" : "Totas las bóstias",
    "Inbox" : "Bóstia de recepcion",
    "Junk" : "Indesirables",
    "Sent" : "Mandats",
    "Trash" : "Escobilhièr",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Message sent" : "Messatge mandat",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Continue to %s" : "Contunhar cap a %s"
},
"nplurals=2; plural=(n > 1);");
